@@ -3,7 +3,8 @@ from django.contrib import admin
 from awl.admintools import make_admin_obj_mixin, fancy_modeladmin
 from awl.tests.models import (Link, Author, Book, Chapter, Driver,
     VehicleMake, VehicleModel)
-from awl.rankedmodel.admintools import admin_link_move_up, admin_link_move_down
+from awl.rankedmodel.admintools import (admin_link_move_up, 
+    admin_link_move_down, admin_move_links)
 
 # ============================================================================
 # Waelsteng Admin Models
@@ -52,11 +53,12 @@ base = fancy_modeladmin('id')
 base.add_displays('name')
 base.add_link('vehiclemodel__vehiclemake')
 base.add_link('vehiclemodel', 'My Vehicle Model', 
-    '{{obj.fullname}} id={{obj.id}}')
+    '{{obj.fullname}} id={{obj.id}}', empty='<i>no model</i>')
 base.add_object('vehiclemodel__vehiclemake')
 base.add_object('vehiclemodel', 'RO Vehicle Model', 
     'RO {{obj.fullname}} id={{obj.id}}')
 base.add_formatted_field('rating', '%0.1f')
+base.add_templated_field('rating', '{{row.name}} {{field}}')
 
 @admin.register(Driver)
 class DriverAdmin(base):
@@ -70,10 +72,10 @@ class VehicleMakeAdmin(admin.ModelAdmin):
 
 base = fancy_modeladmin('id')
 base.add_display('name')
-base.add_display('year', 'YEAR TITLE')
+base.add_display('year', 'YEAR TITLE', empty='<i>no year</i>')
 base.add_fk_link('driver_set', Driver, 'vehiclemodel')
 base.add_fk_link('driver_set', Driver, 'vehiclemodel', 'Driver Title',
-    '{{row.name}} {{count}} {{title}}')
+    '{{row.name}} {{count}} {{title}}', empty='<i>no drivers</i>')
 
 @admin.register(VehicleModel)
 class VehicleModelAdmin(base):
@@ -84,14 +86,16 @@ class VehicleModelAdmin(base):
 # ============================================================================
 
 class RankAdmin(admin.ModelAdmin):
-    list_display = ('name', 'move_up', 'move_down')
+    list_display = ('name', 'move_up', 'move_down', 'move_both')
 
     def move_up(self, obj):
         return admin_link_move_up(obj)
-    move_up.allow_tags = True
     move_up.short_description = 'Move Up Rank'
 
     def move_down(self, obj):
         return admin_link_move_down(obj)
-    move_down.allow_tags = True
     move_down.short_description = 'Move Up Rank'
+
+    def move_both(self, obj):
+        return admin_move_links(obj)
+    move_both.short_description = 'Move Both'
